==> haskell-sandi-0.4.0-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.0
id: sandi-0.4.0-7M70G2RvPACNTKUZaks0u
key: sandi-0.4.0-7M70G2RvPACNTKUZaks0u
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
abi: b2c3274a48ee911272d241935be15571
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/sandi-0.4.0
hs-libraries: HSsandi-0.4.0-7M70G2RvPACNTKUZaks0u
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-67QBPVFU7Mu9oEC9xc41Cq
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.4.0-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.0
id: sandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
key: sandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
abi: 2efae44c70e6f4ecbca74733a2345268
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/sandi-0.4.0
hs-libraries: HSsandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-5u7YE5Ecuce5vjjIFEkula
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
